import React, { PropTypes } from 'react'
import styled, { css } from 'styled-components'
import Box from './Box'

const Styles = {}

Styles.naked = (theme) => `
  background-color: transparent;

  &:hover {
    background-color: ${theme.colors.tint[1]};
  }

  &:active {
    background-color: ${theme.colors.tint[2]};
  }
`

Styles.intent = (val, theme) => {
  const intent = theme.intent[val]
  return `
  background-color: ${intent.default.backgroundColor};
  color: ${intent.default.textColor};
  ${intent.default.boxShadow ? `box-shadow: ${intent.default.boxShadow};` : ''}

  &:hover {
    background-color: ${intent.hover.backgroundColor};
    color: ${intent.hover.textColor};
    ${intent.hover.boxShadow ? `box-shadow: ${intent.hover.boxShadow};` : ''}
  }

  &:focus {
    background-color: ${intent.focus.backgroundColor};
    color: ${intent.focus.textColor};
    ${intent.active.boxShadow ? `box-shadow: ${intent.active.boxShadow};` : ''}
  }

  &:active {
    background-color: ${intent.active.backgroundColor};
    color: ${intent.active.textColor};
    ${intent.active.boxShadow ? `box-shadow: ${intent.active.boxShadow};` : ''}
  }
  `
}

const getStyle = ({ primary, secondary, danger, naked }, theme) => {
  if (primary) return Styles.intent('primary', theme)
  if (danger) return Styles.intent('danger', theme)
  if (naked) return Styles.naked(theme)
  if (secondary) return Styles.intent('secondary', theme) /* default */
  return ''
}

const styles = ({
  primary,
  secondary,
  danger,
  naked,
  theme
}) => css`
  text-transform: capitalize;
  border: 0;
  display: inline-block;
  line-height: ${theme.type.body[1].lineHeight};
  font-size: ${theme.type.body[1].fontSize};
  font-weight: 400;
  text-decoration: none;
  transition: 120ms;
  transition-property: background-color, color, box-shadow, opacity;
  cursor: pointer;
  padding: 10px 20px;
  text-align: center;
  white-space: nowrap;
  user-select: none;

  ${getStyle({ primary, secondary, danger, naked }, theme)}

  &:active,
  &:focus {
    outline: none;
  }
`

const Button = styled(({ primary, secondary, danger, naked, ...props }) =>
  React.createElement(Box, props))`${styles}`

Button.propTypes = {
  ...Box.propTypes,
  primary: PropTypes.bool,
  secondary: PropTypes.bool,
  danger: PropTypes.bool,
  naked: PropTypes.bool
}

Button.defaultProps = {
  is: 'button',
  secondary: true,
  rounded: true
}

Button.displayName = 'Button'

export default Button
