import React, { PropTypes } from 'react'
import styled, { css } from 'styled-components'
import Box from './Box'
import TextStyles from './../utils/TextStyles'

const Styles = {}

Styles.muted = (val) => {
  switch (val) {
    case 1:
    default: return `opacity: 0.85;`
    case 2: return `opacity: 0.7;`
  }
}

const getType = ({ display, mono, caps, body, white }, theme) => {
  if (display) return TextStyles.display(display, theme)
  if (body) return TextStyles.body(body, theme)
  if (mono) return TextStyles.mono(mono, theme)
  if (caps) return TextStyles.caps(caps, theme)
  return ''
}

const getColor = ({ white }, theme) => {
  if (white) return `color: ${theme.colors.white[0]};`
  return ''
}

const getLineHeight = ({ lineHeight }) => {
  if (lineHeight) return `lineHeight: ${lineHeight};`
  return ''
}

const styles = ({
  muted,
  display,
  mono,
  caps,
  body,
  white,
  lineHeight,
  theme
}) => css`
  ${getType({ display, mono, caps, body }, theme)}
  ${getColor({ white }, theme)}
  ${getLineHeight({ lineHeight }, theme)}
  ${muted ? Styles.muted(muted) : ''}
`

const Text = styled(({
    white,
    ...props
  }) => React.createElement(Box, props))`${styles}`

Text.propTypes = {
  ...Box.propTypes,
  lineHeight: PropTypes.string,
  white: PropTypes.bool
}

Text.defaultProps = {
  is: 'p'
}

Text.displayName = 'Text'

export {
  Text,
  Styles
}
