import React, { PropTypes } from 'react'
import styled, { css } from 'styled-components'
import TextStyles from './../utils/TextStyles'

const getType = ({ display, mono, caps, body, white }, theme) => {
  if (display) return TextStyles.display(display, theme)
  if (body) return TextStyles.body(body, theme)
  if (mono) return TextStyles.mono(mono, theme)
  if (caps) return TextStyles.caps(caps, theme)
  return ''
}

const styles = ({
  display,
  body,
  mono,
  caps,
  bold,
  theme
}) => css`
  ${getType({ display, body, mono, caps }, theme)}
  ${bold && `font-weight: 500;`}
`

const withTextStyles = (Comp) => {
  const HoComp = styled(({
    display,
    body,
    mono,
    caps,
    bold,
    ...props
  }) => React.createElement(Comp, props))`${styles}`

  HoComp.propTypes = {
    ...Comp.propTypes,
    display: PropTypes.oneOfType([
      PropTypes.bool,
      PropTypes.oneOf([1, 2, 3, 4])
    ]),
    body: PropTypes.oneOfType([
      PropTypes.bool,
      PropTypes.oneOf([1, 2])
    ]),
    mono: PropTypes.bool,
    caps: PropTypes.oneOfType([
      PropTypes.bool,
      PropTypes.oneOf([1, 2])
    ]),
    bold: PropTypes.bool
  }

  HoComp.displayName = Comp.displayName

  return HoComp
}

export {
  withTextStyles
}
