import React from 'react';
import { storiesOf, action, linkTo } from '@kadira/storybook'
import {
  App,
  Text,
  Code,
  Box,
  Pane,
  Content
} from '../components'

const quickBrownFox = 'The quick brown fox jumps over the lazy dog'

export default function textStory (module) {
  storiesOf('Text', module)
    .add('usage', () => (
      <App flex>
        <Pane white padding={10}>
          <Content markdown>
{`
# Text

The Text component is a \`p\` by default. Implements Box.

* Display, body, caps and mono can't be mixed

\`\`\`
<Text display>Display (1)</Text>
<Text display={2}>Display 2</Text>
<Text display={3}>Display 3</Text>
<Text body>Body (1)</Text>
<Text body={2}>Body 2</Text>
<Text mono>Mono</Text>
<Box width='240px'>
  <Text body truncate>Truncate Text when it gets too long lorem ipsum</Text>
</Box>
\`\`\`

`}
          </Content>
          <Text display>Display (1)</Text>
          <Text display={2}>Display 2</Text>
          <Text display={3}>Display 3</Text>
          <Text body>Body (1)</Text>
          <Text body={2}>Body 2</Text>
          <Text mono>Mono</Text>
          <Box width='240px'>
            <Text body truncate>Truncate Text when it gets too long lorem ipsum</Text>
          </Box>
          <Text body muted>Soft Mute</Text>
          <Text body muted={2}>Mute your text even more</Text>
            <Content markdown>
{`

## Text Styles API

Listed as a reference. Is not unique to \`<Text />\`, but is implemented on Box.

prop | type | description
-----|------|------------
\`body\`    | boolean/1..2 | use body-{1..2} type styles
\`display\`   | boolean/1..4  | use display-{1..4} type styles
\`mono\` | boolean | use mono type styles
\`caps\` | boolean/1..2 | use caps-{1..2} type styles
`}
            </Content>
        </Pane>
      </App>
    ))
    .add('Text Overview', () => (
      <App>
        <Text display>Display (1) Text: <Code>{'<Text display>...</Text>'}</Code></Text>
        <Text display={2}>Display 2 Text: <Code>{'<Text display={2}>...</Text>'}</Code></Text>
        <Text display={3}>Display 3 Text: <Code>{'<Text display={2}>...</Text>'}</Code></Text>
        <Text body>Body (1) Text: <Code>{'<Text body>...</Text>'}</Code></Text>
        <Text body={2}>Body 2 Text: <Code>{'<Text body={2}>...</Text>'}</Code></Text>
        <Text mono>Mono Text: <Code>{'<Text mono>...</Text>'}</Code></Text>
        <div style={{ width: 240 }}>
          <Text body truncate>Truncate Text when it gets too long lorem ipsum</Text>
        </div>
        <Text body muted>Soft Mute your text: <Code>{'<Text muted>...</Text>'}</Code></Text>
        <Text body muted={2}>Mute your text even more: <Code>{'<Text muted={2}>...</Text>'}</Code></Text>
      </App>
    ))
    .add('Display (1) Text', () => (
      <App><Text display>{quickBrownFox}</Text></App>
    ))
    .add('Display 2 Text', () => (
      <App><Text display={2}>{quickBrownFox}</Text></App>
    ))
    .add('Display 3 Text', () => (
      <App><Text display={3}>{quickBrownFox}</Text></App>
    ))
    .add('Body (1) Text', () => (
      <App><Text body>{quickBrownFox}</Text></App>
    ))
    .add('Body 2 Text', () => (
      <App><Text body={2}>{quickBrownFox}</Text></App>
    ))
    .add('Mono Text', () => (
      <App><Text mono>{quickBrownFox}</Text></App>
    ))
    .add('Truncate Text', () => (
      <App>
        <div style={{ width: 240 }}>
          <Text body truncate>Truncate Text when it gets too long lorem ipsum</Text>
        </div>
      </App>
    ))
    .add('Muted (1) Text', () => (
      <App><Text muted>Soft Mute your text: <Code>{'<Text muted>...</Text>'}</Code></Text></App>
    ))
    .add('Muted 2 Text', () => (
      <App><Text muted={2}>Mute your text even more: <Code>{'<Text muted={2}>...</Text>'}</Code></Text></App>
    ))
}
